import { BackendSecret, ConstructFactory, FunctionResources, ResourceProvider } from '@aws-amplify/plugin-types';
/**
 * Entry point for defining a function in the Amplify ecosystem
 */
export declare const defineFunction: (props?: FunctionProps) => ConstructFactory<ResourceProvider<FunctionResources>>;
export type FunctionProps = {
    /**
     * A name for the function.
     * Defaults to the basename of the entry path if specified.
     * If no entry is specified, defaults to the directory name in which this function is defined.
     *
     * Example:
     * If entry is `./scheduled-db-backup.ts` the name will default to "scheduled-db-backup"
     * If entry is not set and the function is defined in `amplify/functions/db-backup/resource.ts` the name will default to "db-backup"
     */
    name?: string;
    /**
     * The path to the file that contains the function entry point.
     * If this is a relative path, it is computed relative to the file where this function is defined
     *
     * Defaults to './handler.ts'
     */
    entry?: string;
    /**
     * An amount of time in seconds between 1 second and 15 minutes.
     * Must be a whole number.
     * Default is 3 seconds.
     */
    timeoutSeconds?: number;
    /**
     * An amount of memory (RAM) to allocate to the function between 128 and 10240 MB.
     * Must be a whole number.
     * Default is 128MB.
     */
    memoryMB?: number;
    /**
     * Environment variables that will be available during function execution
     */
    environment?: Record<string, string | BackendSecret>;
    /**
     * Node runtime version for the lambda environment.
     *
     * Defaults to the oldest NodeJS LTS version. See https://nodejs.org/en/about/previous-releases
     */
    runtime?: NodeVersion;
};
export type NodeVersion = 16 | 18 | 20;
//# sourceMappingURL=factory.d.ts.map